traits Package — mio 0.1.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »

# traits Package

## `traits` Package

class `mio.traits.` `Traits`

  Bases: `mio.object.Object`

  `load_objects`()
  `create_objects`()

## `adaptable` Module

class `mio.traits.adaptable.` `TAdaptable`

  Bases: `mio.trait.Trait`

  `use`(receiver, context, m, trait, resolution=None)
  `delTrait`(receiver, context, m, trait)
  `hasTrait`(receiver, context, m, trait)
  `getTraits`(receiver, context, m)
  `getBehaviors`(receiver, context, m)
  `adapt`(receiver, context, m, trait)

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »